Changes
=======

1.1.0 (2016-08-03)
------------------

- Fixed an incompatibility with ZODB5.  The previously optional and
  ignored version argument to the database ``invalidate`` method is now
  disallowed.

- Drop Python 2.6, 3.2, and 3.3 support. Added Python 3.4 and 3.5 support.

1.0.0 (2015-11-11)
------------------

- Python 3 support contributed by Christian Tismer.

0.1.1 (2010-05-26)
------------------

- Fixed a packaging bug.

0.1.0 (2010-05-20)
------------------

Initial release
